==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/complex/BusinessNotificationParameter.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import microsoft.dynamics.crm.enums.BusinessNotificationParameterType;

@JsonPropertyOrder({
    "@odata.type", 
    "ParameterType", 
    "Data"})
@JsonInclude(Include.NON_NULL)
public class BusinessNotificationParameter implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("ParameterType")
    protected BusinessNotificationParameterType parameterType;

    @JsonProperty("Data")
    protected String data;

    protected BusinessNotificationParameter() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.BusinessNotificationParameter";
    }

    @Property(name="ParameterType")
    @JsonIgnore
    public Optional<BusinessNotificationParameterType> getParameterType() {
        return Optional.ofNullable(parameterType);
    }

    public BusinessNotificationParameter withParameterType(BusinessNotificationParameterType parameterType) {
        BusinessNotificationParameter _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.BusinessNotificationParameter");
        _x.parameterType = parameterType;
        return _x;
    }

    @Property(name="Data")
    @JsonIgnore
    public Optional<String> getData() {
        return Optional.ofNullable(data);
    }

    public BusinessNotificationParameter withData(String data) {
        Checks.checkIsAscii(data);
        BusinessNotificationParameter _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.BusinessNotificationParameter");
        _x.data = data;
        return _x;
    }

    public BusinessNotificationParameter withUnmappedField(String name, String value) {
        BusinessNotificationParameter _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private BusinessNotificationParameterType parameterType;
        private String data;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder parameterType(BusinessNotificationParameterType parameterType) {
            this.parameterType = parameterType;
            this.changedFields = changedFields.add("ParameterType");
            return this;
        }

        public Builder data(String data) {
            this.data = data;
            this.changedFields = changedFields.add("Data");
            return this;
        }

        public BusinessNotificationParameter build() {
            BusinessNotificationParameter _x = new BusinessNotificationParameter();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.BusinessNotificationParameter";
            _x.parameterType = parameterType;
            _x.data = data;
            return _x;
        }
    }

    private BusinessNotificationParameter _copy() {
        BusinessNotificationParameter _x = new BusinessNotificationParameter();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.parameterType = parameterType;
        _x.data = data;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("BusinessNotificationParameter[");
        b.append("ParameterType=");
        b.append(this.parameterType);
        b.append(", ");
        b.append("Data=");
        b.append(this.data);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.89-sources.jar: microsoft/dynamics/crm/complex/BusinessNotificationParameter.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import microsoft.dynamics.crm.enums.BusinessNotificationParameterType;

@JsonPropertyOrder({
    "@odata.type", 
    "ParameterType", 
    "Data"})
@JsonInclude(Include.NON_NULL)
public class BusinessNotificationParameter implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("ParameterType")
    protected BusinessNotificationParameterType parameterType;

    @JsonProperty("Data")
    protected String data;

    protected BusinessNotificationParameter() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.BusinessNotificationParameter";
    }

    @Property(name="ParameterType")
    @JsonIgnore
    public Optional<BusinessNotificationParameterType> getParameterType() {
        return Optional.ofNullable(parameterType);
    }

    public BusinessNotificationParameter withParameterType(BusinessNotificationParameterType parameterType) {
        BusinessNotificationParameter _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.BusinessNotificationParameter");
        _x.parameterType = parameterType;
        return _x;
    }

    @Property(name="Data")
    @JsonIgnore
    public Optional<String> getData() {
        return Optional.ofNullable(data);
    }

    public BusinessNotificationParameter withData(String data) {
        Checks.checkIsAscii(data);
        BusinessNotificationParameter _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.BusinessNotificationParameter");
        _x.data = data;
        return _x;
    }

    public BusinessNotificationParameter withUnmappedField(String name, String value) {
        BusinessNotificationParameter _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private BusinessNotificationParameterType parameterType;
        private String data;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder parameterType(BusinessNotificationParameterType parameterType) {
            this.parameterType = parameterType;
            this.changedFields = changedFields.add("ParameterType");
            return this;
        }

        public Builder data(String data) {
            this.data = data;
            this.changedFields = changedFields.add("Data");
            return this;
        }

        public BusinessNotificationParameter build() {
            BusinessNotificationParameter _x = new BusinessNotificationParameter();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.BusinessNotificationParameter";
            _x.parameterType = parameterType;
            _x.data = data;
            return _x;
        }
    }

    private BusinessNotificationParameter _copy() {
        BusinessNotificationParameter _x = new BusinessNotificationParameter();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.parameterType = parameterType;
        _x.data = data;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("BusinessNotificationParameter[");
        b.append("ParameterType=");
        b.append(this.parameterType);
        b.append(", ");
        b.append("Data=");
        b.append(this.data);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
